@@ -2,6 +2,7 @@ import datetime
 from decimal import Decimal
 
 from django.core.serializers.json import DjangoJSONEncoder
+from django.utils import six
 
 
 class TZAwareJSONEncoder(DjangoJSONEncoder):
@@ -30,3 +31,14 @@ def default(o):
         return list(o)
 
     raise TypeError(repr(o) + " is not JSON serializable")
+
+
+def _resolve_object_path(dotted_name):
+    if isinstance(dotted_name, six.string_types):
+        path = dotted_name.split('.')
+        module = __import__(dotted_name.rsplit('.', 1)[0])
+        for item in path[1:-1]:
+            module = getattr(module, item)
+        return getattr(module, path[-1])
+
+    return dotted_name
