@@ -11,7 +11,8 @@ class JSONWidget(forms.Textarea):
         if value is None:
             value = ""
         if not isinstance(value, six.string_types):
-            value = json.dumps(value, indent=2, default=default)
+            value = json.dumps(value, ensure_ascii=False, indent=2,
+                               default=default)
         return super(JSONWidget, self).render(name, value, attrs)
 
 
